==> dde-launchpad_0.4.6.tar.xz: BUILD/translations/dde-launchpad_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="30"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="40"/>
        <source>Pin to Top</source>
        <translation>移到顶部</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="49"/>
        <source>Remove from favorites</source>
        <translation>从收藏中移除</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="49"/>
        <source>Add to favorites</source>
        <translation>添加到收藏</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="63"/>
        <source>Send to desktop</source>
        <translation>发送到桌面</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="63"/>
        <source>Remove from desktop</source>
        <translation>从桌面上移除</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="73"/>
        <source>Send to dock</source>
        <translation>发送到任务栏</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="73"/>
        <source>Remove from dock</source>
        <translation>从任务栏上移除</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="84"/>
        <source>Add to startup</source>
        <translation>开机自动启动</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="84"/>
        <source>Remove from startup</source>
        <translation>取消开机自动启动</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="89"/>
        <source>Use a proxy</source>
        <translation>使用代理</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="95"/>
        <source>Disable display scaling</source>
        <translation>禁用屏幕缩放</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="102"/>
        <source>Uninstall</source>
        <translation>卸载</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">网络应用</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">社交沟通</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">音乐欣赏</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">视频播放</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">图形图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">游戏娱乐</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">办公学习</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">阅读翻译</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">编程开发</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">系统管理</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="vanished">其他应用</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="vanished">搜索</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>显示启动器（默认为隐藏）</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>切换启动器的可见性</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="19"/>
        <source>Internet</source>
        <translation>网络应用</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="21"/>
        <source>Chat</source>
        <translation>社交沟通</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="23"/>
        <source>Music</source>
        <translation>音乐欣赏</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="25"/>
        <source>Video</source>
        <translation>视频播放</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="27"/>
        <source>Graphics</source>
        <translation>图形图像</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="29"/>
        <source>Game</source>
        <translation>游戏娱乐</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="31"/>
        <source>Office</source>
        <translation>办公学习</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="33"/>
        <source>Reading</source>
        <translation>阅读翻译</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="35"/>
        <source>Development</source>
        <translation>编程开发</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="37"/>
        <source>System</source>
        <translation>系统管理</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="39"/>
        <source>Others</source>
        <translation>其他应用</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="270"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>您确定要卸载 %1 吗？</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="282"/>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="296"/>
        <source>Confirm</source>
        <translation>确 定</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Categories</source>
        <translation type="vanished">应用分类</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="103"/>
        <source>Power</source>
        <translation>电源</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="361"/>
        <location filename="../qml/WindowedFrame.qml" line="266"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="115"/>
        <source>Control Center</source>
        <translation>控制中心</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="157"/>
        <source>My Favorites</source>
        <translation>收藏应用</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="191"/>
        <source>Add your favorite apps here</source>
        <translation>添加应用到收藏</translation>
    </message>
    <message>
        <location filename="../qml/WindowedFrame.qml" line="202"/>
        <source>All Apps</source>
        <translation>所有应用</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="346"/>
        <location filename="../qml/WindowedFrame.qml" line="230"/>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
</context>
</TS>

==> dde-launchpad_0.6.12.tar.xz: BUILD/translations/dde-launchpad_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AnalysisView</name>
    <message>
        <source>No search results</source>
        <translation type="vanished">无搜索结果</translation>
    </message>
</context>
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="31"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="41"/>
        <source>Pin to Top</source>
        <translation>移到顶部</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Remove from favorites</source>
        <translation>从收藏中移除</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="50"/>
        <source>Add to favorites</source>
        <translation>添加到收藏</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Send to desktop</source>
        <translation>发送到桌面</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="64"/>
        <source>Remove from desktop</source>
        <translation>从桌面上移除</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Send to dock</source>
        <translation>发送到任务栏</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="74"/>
        <source>Remove from dock</source>
        <translation>从任务栏上移除</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Add to startup</source>
        <translation>开机自动启动</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="85"/>
        <source>Remove from startup</source>
        <translation>取消开机自动启动</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="92"/>
        <source>Use a proxy</source>
        <translation>使用代理</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="100"/>
        <source>Disable display scaling</source>
        <translation>禁用屏幕缩放</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="107"/>
        <source>Uninstall</source>
        <translation>卸载</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">网络应用</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">社交沟通</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">音乐欣赏</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">视频播放</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">图形图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">游戏娱乐</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">办公学习</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">阅读翻译</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">编程开发</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">系统管理</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="vanished">其他应用</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="26"/>
        <source>Power</source>
        <translation>电源</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="40"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>Frequently Used</source>
        <translation>我的常用</translation>
    </message>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="29"/>
        <source>All Apps</source>
        <translation>所有应用</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="vanished">搜索</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>显示启动器（默认为隐藏）</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>切换启动器的可见性</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="21"/>
        <source>Internet</source>
        <translation>网络应用</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="23"/>
        <source>Chat</source>
        <translation>社交沟通</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="25"/>
        <source>Music</source>
        <translation>音乐欣赏</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="27"/>
        <source>Video</source>
        <translation>视频播放</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="29"/>
        <source>Graphics</source>
        <translation>图形图像</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="31"/>
        <source>Game</source>
        <translation>游戏娱乐</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="33"/>
        <source>Office</source>
        <translation>办公学习</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="35"/>
        <source>Reading</source>
        <translation>阅读翻译</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="37"/>
        <source>Development</source>
        <translation>编程开发</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="39"/>
        <source>System</source>
        <translation>系统管理</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="41"/>
        <source>Others</source>
        <translation>其他应用</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="313"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>您确定要卸载 %1 吗？</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="325"/>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="339"/>
        <source>Confirm</source>
        <translation>确 定</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="27"/>
        <source>Recently Installed</source>
        <translation>最近安装</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="26"/>
        <source>All Apps</source>
        <translation>所有应用</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="76"/>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="39"/>
        <source>Free sorting</source>
        <translation>自由排序</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="52"/>
        <source>Sort by category</source>
        <translation>按分类</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="64"/>
        <source>Sort by name</source>
        <translation>按名称</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="124"/>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="139"/>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="154"/>
        <source>Documents</source>
        <translation>文档</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="169"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="184"/>
        <source>Control Center</source>
        <translation>控制中心</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Categories</source>
        <translation type="vanished">应用分类</translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="vanished">电源</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">设置</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">搜索</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation type="vanished">控制中心</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="vanished">收藏应用</translation>
    </message>
    <message>
        <source>Add your favorite apps here</source>
        <translation type="vanished">添加应用到收藏</translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="vanished">所有应用</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation type="vanished">无搜索结果</translation>
    </message>
</context>
</TS>
